#ifndef GLITE_WMS_COMMON_REQUESTAD_NODEAD_H
#define GLITE_WMS_COMMON_REQUESTAD_NODEAD_H
/*
 * NodeAdNode.h
 * Copyright (c) 2001 The European Datagrid Project - IST programme, all rights reserved.
 * Contributors are mentioned in the code where appropriate.
 */

#include "JobAd.h"
#include "JdlAttributeList.h"

namespace glite {
namespace wms {
namespace jdl {

/**
 *
 * @brief Provides a representation of the job description in the JDL language
 *
 * @ingroup UserInterface
 * @version 0.1
 * @date 15 April 2002
 * @author Alessandro Maraschini <alessandro.maraschini@datamat.it>
*/
class NodeAd : public glite::wms::jdl::JobAd{
 public:
	/** Default constructor */
	NodeAd():JobAd(){};
	NodeAd(const std::string& jdl):JobAd(){fromString(jdl);};
	/** Constructory by Classad */
	NodeAd(const classad::ClassAd& classAd):JobAd(){fromClassAd(classAd);};
	/** Constructory by NodeAd*/
	NodeAd(const NodeAd& nodead);
	/** Operator "=" performs a deep copy of the JobAd instance  */
	void operator=(const NodeAd& nodead);
	/** Operator = */
	virtual ~NodeAd() throw();
	/** Retrieve the inputSandbox remote files extracted while checking the Ad
	* @return a vector of all the Expression of remote sandbox i.e. all the <node name>_<sbx file> linked in the inputsandbox attribute
	*/
	std::vector<classad::ExprTree*> getRemoteSandbox() ;
	std::vector<std::string> getStringValue(const std::string& attr_name) ;
	/** Add a UserTag to the node
	*@param attr_name the name of the usertag to be added
	*@param attr_value the value for the usertag
	*/
	void addUserTag ( const std::string& attr_name,  const std::string& attr_value );
	void checkSyntax( const std::string& attr_name , classad::Value attr_value )  ;
  protected:
	std::vector<std::string> NodeAd::getISBStrings();
	/** Check InputSandbox value. Could be overloaded in order to perform different checks
	*@param extracted a vector listing all the files that have to be extracted i.e. whoose path has to be solved
	*/
	void checkInputSandbox(  std::vector<std::string>& extracted ) ;
	/** Perform Special checks for VirtualOrganisation attribute
	* Notice: for a NodeAd instance it is not mandatory (as for a JobAd)  */
	void checkSpecials( ) ;
	/**
	* JobAd overloaded method: used to insert an attribute inside the classad
	*@param attr_name the name of the attribute
	*@param val the value of the inserted attribute as a classad expression
	*/
	void insertAttribute(const std::string& attr_name , classad::ExprTree* val);

  private:
	// This vector contains all ISB expr Values, later will be used
	std::vector<classad::ExprTree*> inputRemotes ;
	friend class ExpDagAd ;
};

} // jdl namespace
} // wms namespace
} // glite namespace

#endif

//EOF
