#ifndef GLITE_WMS_COMMON_REQUESTAD_EXTRACTFILES_H
#define GLITE_WMS_COMMON_REQUESTAD_EXTRACTFILES_H
/*
* extractfiles.h
* Copyright (c) 2001 The European Datagrid Project - IST programme, all rights reserved.
* Contributors are mentioned in the code where appropriate.
*/
namespace glite {
namespace wms {
namespace jdl {

	// TBD FUTURE IMPLEMENTATION
	/**
	* Used to specify for a node all
	* the ISB values related

	struct NodeFiles {
		std::string nodeName;
		std::vector<std::string> files;
	};
	
	* Used to specify for a job or a dag
	* all the ISB values related

	struct ExtractedFiles{
		std::vector<std::string> files;
		std::vector<NodeFiles>   nodeFiles;
	};
	*/
	/**
	*
	* @brief Provides a method for extracting files from a specified path
	*
	* @version 0.1
	* @date April 2005
	* @author Alessandro Maraschini <alessandro.maraschini@datamat.it>
	*/
	enum checkType {
		EXISTENCE, /** check if file is actually stored on local machine */
		WMPROXY,   /** create extract files on server side*/
		TRANSFER,  /** create extract files from path and destination URI*/
		ONLYLOCAL  /** create extract files only from local path */
	};
	/**
	* Following the classad rules this method parses the specified path and
	* extract/transform it filling all the resulting matching files depending on called parameter
	*@param attr_name the name of the attribute that is beeing parsed
	*@param path the string representation of the path to be parsed
	*@param extracted a vector where to append matching results
	*@param lookInto_b specify whether to use the client-side ruling approach (true) or the server one (false)
	*@param wmpURI the string representation of the wmproxy Destination URI (needed for server side, empty "" string otherwise)
	*@param isbURI the string representation of the InputSandboxDestUri attribute (if provided, empty "" string otherwise)
	*@return whether the file is stored (or to be stored) on server side (true), that means whether wmpURI has been appended
	*/
	bool extractFiles(const std::string& attr_name , const std::string& path ,
		std::vector<std::string> &extracted,checkType lookInto_b,
		const std::string &wmpURI, const std::string &isbURI) ;
	/**
	* Following the classad rules this method parses the specified paths and
	* extract/transform them filling all the resulting matching files depending on called parameter
	*@param attr_name the name of the attribute that is beeing parsed
	*@param paths the strings representation of all the paths to be parsed
	*@param extracted a vector where to append matching results
	*@param lookInto_b specify whether to use the client-side ruling approach (true) or the server one (false)
	*@param wmpURI the string representation of the wmproxy Destination URI (needed for server side, empty "" string otherwise)
	*@param isbURI the string representation of the InputSandboxDestUri attribute (if provided, empty "" string otherwise)
	*@return whether the file is stored (or to be stored) on server side (true), that means whether wmpURI has been appended
	*/
	bool extractFiles(const std::string& attr_name , std::vector<std::string>& paths ,
		std::vector<std::string> &extracted,checkType lookInto_b,
		const std::string &wmpURI, const std::string &isbURI);

	/**
	* Following the classad rules this method parses the specified path and
	* returns, if necessary, all the files that are to be transfered on remote machine
	*@param attr_name the name of the attribute that is beeing parsed
	*@param path the string representation of the path to be parsed
	*@param wmpURI the string representation of the wmproxy Destination URI (needed for server side, empty "" string otherwise)
	*@param isbURI the string representation of the InputSandboxDestUri attribute (if provided, empty "" string otherwise)
	*@result a vector of pairs. Each pair contains the source and the target string file representation
	*/
	void toBcopied(const std::string& attr_name , const std::string& path ,
		std::vector<std::pair < std::string, std::string> > &result,
		const std::string &wmpURI, const std::string &isbURI);
	/**
	* This method iteratively calls its omonimous toBcopied method for each of its path contained in paths
	*@param attr_name the name of the attribute that is beeing parsed
	*@param paths the string representation of all the paths to be analised
	*@param wmpURI the string representation of the wmproxy Destination URI (needed for server side, empty "" string otherwise)
	*@param isbURI the string representation of the InputSandboxDestUri attribute (if provided, empty "" string otherwise)
	*@result a vector of pairs. Each pair contains the source and the target string file representation
	*/
	void toBcopied(const std::string& attr_name , std::vector<std::string> paths ,
		std::vector<std::pair < std::string, std::string> > &result,
		const std::string &wmpURI, const std::string &isbURI);
} // jdl namespace
} // wms namespace
} // glite namespace
#endif
//EOF
